@@ -23,6 +23,7 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <glib.h>
+#include "config.h"
 #include "contacts-callbacks-ui.h"
 #include "contacts-edit-pane.h"
 #include "contacts-main.h"
@@ -30,8 +31,6 @@
 #include <gconf/gconf-client.h>
 #endif
 
-#define GCONF_PATH "/apps/contacts"
-#define GCONF_KEY_SEARCH "/apps/contacts/search_type"
 
 static GtkWidget *groups_combobox;
 
@@ -68,10 +67,12 @@ groups_combobox_changed_cb (GtkWidget *widget, ContactsData *data)
 {
 	GtkTreeIter iter;
 	gchar *text = NULL;
-	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (groups_combobox), &iter);
-	gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (groups_combobox)), &iter, 0, &text, -1);
-	g_free (data->selected_group);
-	data->selected_group = text;
+	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (groups_combobox), &iter))
+	{
+		gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (groups_combobox)), &iter, 0, &text, -1);
+		g_free (data->selected_group);
+		data->selected_group = text;
+	}
 	contacts_update_treeview (data);
 }
 
@@ -84,11 +85,12 @@ contacts_ui_update_groups_list (ContactsData *data)
 		gtk_list_store_insert_with_values (list, &iter, 1, 0, data, -1);
 	}
 	GtkListStore *list;
+	GtkTreeIter dummy;
 
 	list = (GtkListStore*) gtk_combo_box_get_model (GTK_COMBO_BOX(groups_combobox));
 	if (!list) return;
 	gtk_list_store_clear (list);
-	gtk_list_store_insert_with_values (list, NULL, 0, 0, "All", -1);
+	gtk_list_store_insert_with_values (list, &dummy, 0, 0, "All", -1);
 	g_list_foreach (data->contacts_groups, add_to_list, list);
 
 	/* Select 'All' in the groups combobox if nothing selected */
@@ -163,12 +165,18 @@ create_main_window (ContactsData *data)
 	ContactsUI *ui = data->ui;
 	GtkSizeGroup *size_group;
 
+#ifdef HAVE_GCONF
+	GConfClient *client;
+	gchar *search;
+	gint width, height;
+#endif
+
 	accel_group = gtk_accel_group_new ();
 
 	main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title (GTK_WINDOW (main_window), _("Contacts"));
-	gtk_window_set_default_size (GTK_WINDOW (main_window), -1, 300);
-	gtk_window_set_icon_name (GTK_WINDOW (main_window), "stock_contact");
+	gtk_window_set_icon_name (GTK_WINDOW (main_window), "contacts");
+	gtk_window_set_default_size (GTK_WINDOW (main_window), 320, 240);
 
 	vbox7 = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (main_window), vbox7);
@@ -205,6 +213,7 @@ create_main_window (ContactsData *data)
 
 	contact_menu = gtk_menu_item_new_with_mnemonic (_("_Contact"));
 	gtk_container_add (GTK_CONTAINER (main_menubar), contact_menu);
+	g_object_set (G_OBJECT (contact_menu), "no-show-all", TRUE, NULL);
 
 	contact_menu_menu = gtk_menu_new ();
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (contact_menu), contact_menu_menu);
@@ -257,7 +266,6 @@ create_main_window (ContactsData *data)
 
 	main_hpane = gtk_hpaned_new ();
 	gtk_container_add (GTK_CONTAINER (main_notebook), main_hpane);
-	gtk_paned_set_position (GTK_PANED (main_hpane), 1);
 
 	contacts_vbox = gtk_vbox_new (FALSE, 6);
 	gtk_paned_pack1 (GTK_PANED (main_hpane), contacts_vbox, FALSE, FALSE);
@@ -300,6 +308,7 @@ create_main_window (ContactsData *data)
 
 	search_tab_hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (search_hbox), search_tab_hbox, TRUE, TRUE, 0);
+	g_object_set (G_OBJECT (search_tab_hbox), "no-show-all", TRUE, NULL);
 
 	symbols_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("0-9#"));
 	gtk_box_pack_start (GTK_BOX (search_tab_hbox), symbols_radiobutton, TRUE, FALSE, 0);
@@ -337,7 +346,7 @@ create_main_window (ContactsData *data)
 	preview_header_hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (summary_vbox), preview_header_hbox, FALSE, TRUE, 0);
 
-	summary_name_label = gtk_label_new (_("<span><big><b>Welcome to Contacts</b></big></span>"));
+	summary_name_label = gtk_label_new (NULL);
 	gtk_box_pack_start (GTK_BOX (preview_header_hbox), summary_name_label, TRUE, TRUE, 0);
 	GTK_WIDGET_SET_FLAGS (summary_name_label, GTK_CAN_FOCUS);
 	gtk_label_set_use_markup (GTK_LABEL (summary_name_label), TRUE);
@@ -346,7 +355,7 @@ create_main_window (ContactsData *data)
 	gtk_misc_set_padding (GTK_MISC (summary_name_label), 6, 0);
 	gtk_label_set_ellipsize (GTK_LABEL (summary_name_label), PANGO_ELLIPSIZE_END);
 
-	photo_image = gtk_image_new_from_icon_name ("stock_contact", GTK_ICON_SIZE_DIALOG);
+	photo_image = gtk_image_new ();
 	gtk_box_pack_end (GTK_BOX (preview_header_hbox), photo_image, FALSE, TRUE, 6);
 	gtk_misc_set_padding (GTK_MISC (photo_image), 1, 0);
 
@@ -364,7 +373,8 @@ create_main_window (ContactsData *data)
 
 	summary_hbuttonbox = gtk_hbutton_box_new ();
 	gtk_box_pack_end (GTK_BOX (vbox3), summary_hbuttonbox, FALSE, FALSE, 0);
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (summary_hbuttonbox), GTK_BUTTONBOX_SPREAD);
+	gtk_button_box_set_layout (GTK_BUTTON_BOX (summary_hbuttonbox), GTK_BUTTONBOX_END);
+	gtk_box_set_spacing (GTK_BOX (summary_hbuttonbox), 6);
 
 	new_button = gtk_button_new_from_stock ("gtk-new");
 	gtk_container_add (GTK_CONTAINER (summary_hbuttonbox), new_button);
@@ -400,6 +410,7 @@ create_main_window (ContactsData *data)
 	hbuttonbox2 = gtk_hbutton_box_new ();
 	gtk_box_pack_start (GTK_BOX (vbox4), hbuttonbox2, FALSE, TRUE, 0);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox2), GTK_BUTTONBOX_END);
+	gtk_box_set_spacing (GTK_BOX (hbuttonbox2), 6);
 
 	add_field_button = gtk_button_new_with_mnemonic (_("_Add Field"));
 	gtk_container_add (GTK_CONTAINER (hbuttonbox2), add_field_button);
@@ -428,6 +439,9 @@ create_main_window (ContactsData *data)
 
 
 	/* connect signals */
+	g_signal_connect (G_OBJECT (main_window), "delete-event",
+			G_CALLBACK (contacts_main_window_delete_event_cb), data);
+
 	g_signal_connect ((gpointer) main_window, "destroy",
 			G_CALLBACK (gtk_main_quit),
 			NULL);
@@ -451,7 +465,7 @@ create_main_window (ContactsData *data)
 			GTK_OBJECT (main_window));
 	g_signal_connect_swapped ((gpointer) about1, "activate",
 			G_CALLBACK (contacts_about_cb),
-			NULL);
+			main_window);
 	g_signal_connect_swapped ((gpointer) groups_combobox, "changed",
 			G_CALLBACK (contacts_update_treeview),
 			data);
@@ -542,25 +556,27 @@ create_main_window (ContactsData *data)
 	ui->summary_table = summary_table;
 	ui->summary_vbox = summary_vbox;
 
-	gtk_widget_show_all (main_window);
-	gtk_widget_hide (search_tab_hbox);
-	gtk_widget_hide (contact_menu);
-
-
 #ifdef HAVE_GCONF
 	client = gconf_client_get_default ();
 	search = gconf_client_get_string (client, GCONF_KEY_SEARCH, NULL);
 	if (!search) {
 		gconf_client_set_string (
 			client, GCONF_KEY_SEARCH, "entry", NULL);
-	} else if (strcmp (search, "alphatab") == 0) {
-		gtk_widget_hide (search_entry_hbox);
-		gtk_widget_show (search_tab_hbox);
+	} else {
+		if (strcmp (search, "alphatab") == 0) {
+			gtk_widget_hide (search_entry_hbox);
+			gtk_widget_show (search_tab_hbox);
+		}
+		g_free (search);
 	}
 	gconf_client_add_dir (client, GCONF_PATH, GCONF_CLIENT_PRELOAD_NONE,
 		NULL);
 	gconf_client_notify_add (client, GCONF_KEY_SEARCH,
-		contacts_gconf_search_cb, xml, NULL, NULL);
+		contacts_gconf_search_cb, data, NULL, NULL);
+
+	width = gconf_client_get_int (client, GCONF_PATH "/width", NULL);
+	height = gconf_client_get_int (client, GCONF_PATH "/height", NULL);
+	gtk_window_set_default_size (GTK_WINDOW (main_window), width, height);
 #endif
 
 }
